@@ -245,7 +245,7 @@ def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwa
         if (
             option not in kwargs
             and not option.startswith("__")
-            and option not in ["read_package_file", "warn_on_unexpected_types"]
+            and option not in ["read_package_file"]
         ):
             kwargs[option] = getattr(opt, option)
 
@@ -263,8 +263,6 @@ def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwa
     css = kwargs.pop("css")
     tags = kwargs.pop("tags")
 
-    _set_dom_equals_t_if_df_fits_in_one_page(df, kwargs)
-
     if caption is not None:
         tags = '{}<caption style="white-space: nowrap; overflow: hidden">{}</caption>'.format(
             tags, caption
@@ -276,6 +274,8 @@ def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwa
     maxColumns = kwargs.pop("maxColumns", pd.get_option("display.max_columns") or 0)
     eval_functions = kwargs.pop("eval_functions", None)
     pre_dt_code = kwargs.pop("pre_dt_code")
+    warn_on_unexpected_types = kwargs.pop("warn_on_unexpected_types", False)
+    warn_on_int_to_str_conversion = kwargs.pop("warn_on_int_to_str_conversion", False)
 
     if isinstance(df, (np.ndarray, np.generic)):
         df = pd.DataFrame(df)
@@ -303,6 +303,9 @@ def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwa
             )
         )
 
+    if "dom" not in kwargs and _df_fits_in_one_page(df, kwargs):
+        kwargs["dom"] = "ti" if downsampling_warning else "t"
+
     footer = kwargs.pop("footer")
     column_filters = kwargs.pop("column_filters")
     if column_filters == "header":
@@ -389,7 +392,12 @@ def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwa
     # When the header has an extra column, we add
     # an extra empty column in the table data #141
     column_count = _column_count_in_header(table_header)
-    dt_data = datatables_rows(df, column_count)
+    dt_data = datatables_rows(
+        df,
+        column_count,
+        warn_on_unexpected_types=warn_on_unexpected_types,
+        warn_on_int_to_str_conversion=warn_on_int_to_str_conversion,
+    )
 
     output = replace_value(
         output, "const data = [];", "const data = {};".format(dt_data)
@@ -415,14 +423,9 @@ def _min_rows(kwargs):
     return min_rows[0]
 
 
-def _set_dom_equals_t_if_df_fits_in_one_page(df, kwargs):
+def _df_fits_in_one_page(df, kwargs):
     """Display just the table (not the search box, etc...) if the rows fit on one 'page'"""
-    if "dom" in kwargs:
-        return
-
-    if len(df) <= _min_rows(kwargs):
-        kwargs["dom"] = "t"
-        return
+    return len(df) <= _min_rows(kwargs)
 
 
 def safe_reset_index(df):
