@@ -46,3 +46,6 @@ css = read_package_file("html/itables.css")
 
 """Should a warning appear when we have to encode an unexpected type?"""
 warn_on_unexpected_types = True
+
+"""Should a warning appear when we convert large integers to str?"""
+warn_on_int_to_str_conversion = True
